# -*- coding: utf-8 -*-
from Plugins.Bp.geminimain.gLocale import _
from Plugins.Bp.geminimain.gTools import cleanexit, pathExists
from Plugins.Bp.geminimain.FileBrowser import gBrowser, FILTER_MVI, FILTER_JPEG
from Plugins.Bp.geminimain.WidgetConfig import gConfigWindow, gConfigDirectory
from Plugins.Bp.geminimain.WidgetMessageBox import gMessageBox
from Plugins.Bp.geminimain.plugin import cgevent
from Plugins.Bp.geminimain.lib.libpicview import ePicViewer

from enigma import eConsoleAppContainer
from Screens.MessageBox import MessageBox
from Components.config import config, NoSave, getConfigListEntry
from Tools.Directories import copyfile

from os import system as os_system

#---------------------------------------------------------------------
FILTER_LOGO = FILTER_MVI | FILTER_JPEG
MI_RESIZEJPEG = 8
#---------------------------------------------------------------------

BOOT_LOGO="/usr/share/dreambox-bootlogo/backdrop.mvi"
RADIO_LOGO="/usr/share/enigma2/radio.mvi"
GP_BOOT_LOGO="/usr/share/dreambox-bootlogo/backdrop_gemini.mvi"
GP_RADIO_LOGO="/usr/share/enigma2/radio_gemini.mvi"

class ConfigBootlogo(gConfigWindow ):
	
	def __init__(self, session):
		self.session = session
		self.lastService = self.session.nav.getCurrentlyPlayingServiceReference()
		self.session.nav.stopService()
		self.__bootlogo = cgevent.getConfig("Bootlogo",BOOT_LOGO)
		self.__radiologo = cgevent.getConfig("Radiologo",RADIO_LOGO)
		
		self.picture = ""
		self.mvifile = ""
		
		config.bp.bootlogo = NoSave(gConfigDirectory(default=self.__bootlogo, visible_width=60, filter=FILTER_MVI))
		config.bp.radiologo = NoSave(gConfigDirectory(default=self.__radiologo, visible_width=60, filter=FILTER_MVI))

		list =[]
		list.append(getConfigListEntry(_("Boot Logo"), config.bp.bootlogo))
		list.append(getConfigListEntry(_("Radio Logo"), config.bp.radiologo))

		gConfigWindow.__init__ (self, session, _("Setup Bootlogo"), redbutton=_("convert jpg"), greenbutton=_("Save"), list=list, icon="geminibootlogo/icon_bootlogo.png")
		self.onLayoutFinish.append(self.__onLayoutFinish)
		
	def __onLayoutFinish(self):
		os_system("systemctl start showiframe-backdrop")
		self.SetLabel(_("press Ok for edit Bootlogo"))
		
	def __refresh(self):
		if self.getCurrendValue() == config.bp.bootlogo:
			if config.bp.bootlogo.value != self.__bootlogo and pathExists(config.bp.bootlogo.value):
				os_system("/usr/bin/showiframe %s" %config.bp.bootlogo.value)
			else:
				os_system("/usr/bin/showiframe /usr/share/dreambox-bootlogo/backdrop.mvi")
			self.SetLabel(_("press Ok for edit Bootlogo"))
		elif self.getCurrendValue() == config.bp.radiologo:
			self.SetLabel(_("press Ok for edit Radiologo"))
			if config.bp.radiologo.value != self.__radiologo and pathExists(config.bp.radiologo.value):
				os_system("/usr/bin/showiframe %s" %config.bp.radiologo.value)
			else:
				os_system("/usr/bin/showiframe /usr/share/enigma2/radio.mvi")

	def KeyUp(self):
		gConfigWindow.KeyUp(self)
		self.__refresh()
			
	def KeyDown(self):
		gConfigWindow.KeyDown(self)
		self.__refresh()
		
	def KeyGreen(self):
		if config.bp.bootlogo.value != self.__bootlogo:
			copyfile(config.bp.bootlogo.value, BOOT_LOGO)
			copyfile(BOOT_LOGO, GP_BOOT_LOGO)
			cgevent.setConfig("Bootlogo",config.bp.bootlogo.value)
			
		if config.bp.radiologo.value != self.__radiologo:
			copyfile(config.bp.bootlogo.value, RADIO_LOGO)
			copyfile(RADIO_LOGO, GP_RADIO_LOGO)
			cgevent.setConfig("Radiologo",config.bp.radiologo.value)
			
		self.KeyExit()
		
	def KeyRed(self):
		self.session.openWithCallback(self.__pixCallback, gBrowser, setPath=cgevent.getConfig("Bootlogo_lastdir", "/media/"), filter=FILTER_JPEG)
		
	def __pixCallback(self, file=None):
		if file is None:
			return
		self.picture = file
		cgevent.setConfig("Bootlogo_lastdir", file)
		self.session.openWithCallback(self.__resolutionMviCallback, MessageBox, _("Use FullHD (1080p) resolution?"), MessageBox.TYPE_YESNO, timeout = 10, default = False)
				
	def __resolutionMviCallback(self, val):
		if val:
			x = 1920
			y = 1080
		else:
			x = 1280
			y = 720
		#if self.__currentEntry[2] == "bootlogo_jpg.jpg":
		#	self.__convertPix(x,y, self.__directory + "/" + self.__currentEntry[2][:-4] + ".jpg")
		#else:
		self.__convertPix(x,y)
			
	def __convertPix(self, x, y, copyto=None):
		self.mvifile = self.picture[:self.picture.rfind('.')] + ".mvi"
		self.session.openWithCallback(self.__showLogo, LogoConverter, self.picture, self.mvifile, x, y, copyto)
		
	def __showLogo(self, val):
		print ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>showLogo<<",val
		if val is not None:
			os_system("/usr/bin/showiframe %s"%val)
			if self.getCurrendValue() == config.bp.bootlogo:
				config.bp.bootlogo.value = val
		
			elif self.getCurrendValue() == config.bp.radiologo:
				config.bp.radiologo.value = val
		
	def KeyExit(self):
		self.session.nav.playService(self.lastService)
		self.close()
		cleanexit(__name__)
		

#-----------------------------------------------------------------------------------------------------

class LogoConverter(gMessageBox):

	def __init__(self, session, file, target, x, _y, copyto=None):
		timeout = 0
		text = _("One moment please...")
		if pathExists('/usr/bin/jpeg2yuv')==False or pathExists('/usr/bin/mpeg2enc')==False:
			text = _("Missing converter tools")
			timeout = 5
		
		gMessageBox.__init__ (self, session, title = _("Bootlogo Converter"), icon="geminibootlogo/mess_convert.png", text=text, timeout=timeout)
		y = _y if _y != 1080 else 1088

		self.__ePicViewer = ePicViewer()
		self.__ePicViewer.callback = self.__FinishedTransform

		if copyto is not None:
			self.__ePicViewer.startTransform(file, copyto,x, _y,FILTER_JPEG,1)
		else:
			self.__ePicViewer.startTransform(file, target,x, y,FILTER_MVI,1)

	def __FinishedTransform(self,val,ret):
		#print "_____________________FinishedTransform"
		if val==1:
			self.Exit(ret)
		else:
			self.setText(ret)#Fehlermeldung
			self.StartTimer(5)

	def Exit(self, res=None):
		del self.__ePicViewer
		self.close(res)
		
#-----------------------------------------------------------------------------------------------------